( cd usr/doc/gnupg-1.4.9 ; rm -rf FAQ )
( cd usr/doc/gnupg-1.4.9 ; ln -sf /usr/share/gnupg/FAQ FAQ )
( cd usr/doc/gnupg-1.4.9 ; rm -rf faq.html )
( cd usr/doc/gnupg-1.4.9 ; ln -sf /usr/share/gnupg/faq.html faq.html )
